@@ -10,19 +10,19 @@ use crate::error::Error;
 use crate::money::Currency;
 
 #[derive(Serialize, Deserialize, JsonSchema)]
-pub struct StandardPathParams {
+pub struct IdParam {
     pub id: String,
 }
 
 #[derive(Serialize, Deserialize, JsonSchema)]
-pub struct CreateBodyParams {
+pub struct CreateParams {
     pub currency: Currency,
     pub contact: Option<Contact>,
     pub shipping_address: Option<Address>,
 }
 
 #[derive(Serialize, Deserialize, JsonSchema)]
-pub struct AddOrRemoveItemBodyParams {
+pub struct AddOrRemoveItemParams {
     pub sku: String,
     pub quantity: u64,
 }
